pub fn clear_active_stack()Expand description
Clears the persisted stack. Called by the upper layer after a non-bleed print (which appends \x1b[0m, so the terminal is back to a clean slate).
pub fn clear_active_stack()Clears the persisted stack. Called by the upper layer after a non-bleed print (which appends \x1b[0m, so the terminal is back to a clean slate).